@@ -1,8 +1,8 @@
-__version__ = "0.1.4"
-__author__ = 'DeerMaximum'
+__version__ = "1.2.0"
+__author__ = "DeerMaximum"
 
-from .cmi import CMI
-from .device import Device
-from .channel import Channel
 from .baseApi import ApiError, InvalidCredentialsError, RateLimitError
+from .channel import Channel
+from .cmi import CMI
 from .const import ChannelMode, ChannelType, Languages
+from .device import Device, InvalidDeviceError
